/*******************************************************************************
* Copyright 2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include <string.h>
#include <cytypes.h>
#include <cydevice.h>
#include <cydevice_trm.h>
#include <cyfitter.h>
#include <CyLib.h>
#include <CyDmac.h>
#include <cyfitter_cfg.h>

/* Clock startup error codes                                                   */
#define CYCLOCKSTART_NO_ERROR    0
#define CYCLOCKSTART_XTAL_ERROR  1
#define CYCLOCKSTART_32KHZ_ERROR 2
#define CYCLOCKSTART_PLL_ERROR   3

/*******************************************************************************
* Function Name: CyClockStartupError
********************************************************************************
* Summary:
*  If an error is encountered during clock configuration (crystal startup error,
*  PLL lock error, etc) the system will end up here.  Unless reimplemented by 
*  the customer, an infinite loop will be encountered.
*
* Parameters:  
*   void.
*
*
* Return:
*   void.
*
*******************************************************************************/
#if defined(__GNUC__) || defined(__ARMCC_VERSION)
__attribute__ ((unused))
#endif
static void CyClockStartupError(uint8 errorCode)
{
    /* To remove the compiler warning if errorCode not used.                */
    errorCode = errorCode;

    /* `#START CyClockStartupError` */

    /* If we have a clock startup error (bad MHz crystal, PLL lock, etc)    */
    /* we will end up here to allow the customer to implement something to  */
    /* deal with the clock condition.                                       */

    /* `#END` */

    /* If nothing else, stop here since the clocks have not started         */
    /* correctly.                                                           */
    while(1) {}
}

/* This file contains the data used to initialize the device. */

#undef CYCODE
#undef CYDATA
#undef CYXDATA
#undef CYFAR
#if defined(__C51__) || defined(__CX51__)
#define CYCODE code
#define CYDATA data
#define CYXDATA xdata
#define CYFAR far
extern void cymemzero(void CYFAR *addr, uint16 size);
extern void cyconfigcpy(uint16 size, const void CYFAR *src, void CYFAR *dest) small;
extern void cyconfigcpycode(uint16 size, const void CYCODE *src, void CYFAR *dest);
#define CYMEMZERO(a,c) cymemzero((a),(c))
#define CYCONFIGCPY(d,s,c) cyconfigcpy((c),(s),(d))
#define CYCONFIGCPYCODE(d,s,c) cyconfigcpycode((c),(s),(d))
#else
#define CYCODE
#define CYDATA
#define CYXDATA
#define CYFAR
#define CYMEMZERO(a,c) cymemset((a),0,(c))
#define CYCONFIGCPY(d,s,c) cymemcpy((d),(s),(c))
#define CYCONFIGCPYCODE(d,s,c) cymemcpy((d),(s),(c))
#endif

#if defined(__GNUC__) || defined(__ARMCC_VERSION)
#define CYPACKED __attribute__ ((packed))
#define CYALIGNED __attribute__ ((aligned))
#if CYDEV_CONFIGURATION_DMA
#define DMAINITSEC __attribute__ ((section (".dma_init")))
#else
#define DMAINITSEC
#endif
#if defined(__ARMCC_VERSION)
#define CY_CFG_MEMORY_BARRIER() __memory_changed()
#else
#define CY_CFG_MEMORY_BARRIER() __sync_synchronize()
#endif
#else
/* Keil C51 and others */
#define CYPACKED
#define CYALIGNED
#define DMAINITSEC
#define CY_CFG_MEMORY_BARRIER()
#endif

typedef struct {
	void CYFAR *address;
	uint16 size;
} CYPACKED cfg_memset_t;

typedef struct {
	void CYFAR *dest;
	const void CYFAR *src;
	uint16 size;
} CYPACKED cfg_memcpy_t;

/* TD structure for big-endian systems
 * Requires 2-byte endian swap */
struct td_t {
	uint16 size;
	uint8 flags;
	uint8 next_td_ptr;
	uint16 src;
	uint16 dest;
} CYPACKED;


#if defined(__C51__) || defined(__CX51__)
#define CYMEMZERO8(a,c) cymemzero((a),(c))
#define CYCONFIGCPY8(d,s,c) cyconfigcpy((c),(s),(d))
#define CYCONFIGCPYCODE8(d,s,c) cyconfigcpycode((c),(s),(d))
#else
#if defined(__GNUC__) || defined(__ARMCC_VERSION)
__attribute__ ((unused))
#endif
static void cymemzero8(void *addr, unsigned int count)
{
	volatile uint8 *addr8 = (uint8 *)addr;
	while (count--)
	{
		*addr8 = 0;
		addr8++;
	}
}

#if defined(__GNUC__) || defined(__ARMCC_VERSION)
__attribute__ ((unused))
#endif
static void cymemcpy8(void *dest, const void *src, unsigned int count)
{
	volatile uint8 *dest8 = (uint8 *)dest;
	const uint8 *src8 = (const uint8 *)src;

	while (count--)
	{
		*dest8 = *src8;
		dest8++;
		src8++;
	}
}

#define CYMEMZERO8(a,c) cymemzero8((a),(c))
#define CYCONFIGCPY8(d,s,c) cymemcpy8((d),(s),(c))
#define CYCONFIGCPYCODE8(d,s,c) cymemcpy8((d),(s),(c))
#endif

/* IDMUX_IRQ Address: CYDEV_IDMUX_IRQ_CTL0 Size (bytes): 8 */
#define BS_IDMUX_IRQ_VAL ((const uint8 CYFAR *)0x080000)

/* UDB_1_4_1_CONFIG Address: CYDEV_UCFG_B0_P1_U0_BASE Size (bytes): 128 */
#define BS_UDB_1_4_1_CONFIG_VAL ((const uint8 CYFAR *)0x080008)

/* UDB_1_4_0_CONFIG Address: CYDEV_UCFG_B0_P1_U1_BASE Size (bytes): 128 */
#define BS_UDB_1_4_0_CONFIG_VAL ((const uint8 CYFAR *)0x080088)

/* UDB_1_3_0_CONFIG Address: CYDEV_UCFG_B0_P2_U0_BASE Size (bytes): 128 */
#define BS_UDB_1_3_0_CONFIG_VAL ((const uint8 CYFAR *)0x080108)

/* UDB_1_3_1_CONFIG Address: CYDEV_UCFG_B0_P2_U1_BASE Size (bytes): 128 */
#define BS_UDB_1_3_1_CONFIG_VAL ((const uint8 CYFAR *)0x080188)

/* UDB_1_2_1_CONFIG Address: CYDEV_UCFG_B0_P3_U0_BASE Size (bytes): 128 */
#define BS_UDB_1_2_1_CONFIG_VAL ((const uint8 CYFAR *)0x080208)

/* UDB_1_2_0_CONFIG Address: CYDEV_UCFG_B0_P3_U1_BASE Size (bytes): 128 */
#define BS_UDB_1_2_0_CONFIG_VAL ((const uint8 CYFAR *)0x080288)

/* UDB_0_2_1_CONFIG Address: CYDEV_UCFG_B0_P4_U0_BASE Size (bytes): 128 */
#define BS_UDB_0_2_1_CONFIG_VAL ((const uint8 CYFAR *)0x080308)

/* UDB_0_2_0_CONFIG Address: CYDEV_UCFG_B0_P4_U1_BASE Size (bytes): 128 */
#define BS_UDB_0_2_0_CONFIG_VAL ((const uint8 CYFAR *)0x080388)

/* UDB_0_3_0_CONFIG Address: CYDEV_UCFG_B0_P5_U0_BASE Size (bytes): 128 */
#define BS_UDB_0_3_0_CONFIG_VAL ((const uint8 CYFAR *)0x080408)

/* UDB_0_3_1_CONFIG Address: CYDEV_UCFG_B0_P5_U1_BASE Size (bytes): 128 */
#define BS_UDB_0_3_1_CONFIG_VAL ((const uint8 CYFAR *)0x080488)

/* UDB_0_4_1_CONFIG Address: CYDEV_UCFG_B0_P6_U0_BASE Size (bytes): 128 */
#define BS_UDB_0_4_1_CONFIG_VAL ((const uint8 CYFAR *)0x080508)

/* UDB_0_5_1_CONFIG Address: CYDEV_UCFG_B0_P7_U1_BASE Size (bytes): 128 */
#define BS_UDB_0_5_1_CONFIG_VAL ((const uint8 CYFAR *)0x080588)

/* UDB_1_0_0_CONFIG Address: CYDEV_UCFG_B1_P2_U0_BASE Size (bytes): 128 */
#define BS_UDB_1_0_0_CONFIG_VAL ((const uint8 CYFAR *)0x080608)

/* UDB_1_0_1_CONFIG Address: CYDEV_UCFG_B1_P2_U1_BASE Size (bytes): 128 */
#define BS_UDB_1_0_1_CONFIG_VAL ((const uint8 CYFAR *)0x080688)

/* UDB_1_1_1_CONFIG Address: CYDEV_UCFG_B1_P3_U0_BASE Size (bytes): 128 */
#define BS_UDB_1_1_1_CONFIG_VAL ((const uint8 CYFAR *)0x080708)

/* UDB_1_1_0_CONFIG Address: CYDEV_UCFG_B1_P3_U1_BASE Size (bytes): 128 */
#define BS_UDB_1_1_0_CONFIG_VAL ((const uint8 CYFAR *)0x080788)

/* UDB_0_1_1_CONFIG Address: CYDEV_UCFG_B1_P4_U0_BASE Size (bytes): 128 */
#define BS_UDB_0_1_1_CONFIG_VAL ((const uint8 CYFAR *)0x080808)

/* UDB_0_0_0_CONFIG Address: CYDEV_UCFG_B1_P5_U0_BASE Size (bytes): 128 */
#define BS_UDB_0_0_0_CONFIG_VAL ((const uint8 CYFAR *)0x080888)

/* UDB_0_0_1_CONFIG Address: CYDEV_UCFG_B1_P5_U1_BASE Size (bytes): 128 */
#define BS_UDB_0_0_1_CONFIG_VAL ((const uint8 CYFAR *)0x080908)

/* UWRK_B0_WRK_STATCTL_BITS Address: CYDEV_UWRK_UWRK8_B0_BASE + 0x00000070 Size (bytes): 32 */
#define BS_UWRK_B0_WRK_STATCTL_BITS_VAL ((const uint8 CYFAR *)0x080988)

/* UWRK_B1_WRK_STATCTL_BITS Address: CYDEV_UWRK_UWRK8_B1_BASE + 0x00000070 Size (bytes): 32 */
#define BS_UWRK_B1_WRK_STATCTL_BITS_VAL ((const uint8 CYFAR *)0x0809A8)

/* DSISWITCH_0_2 Address: CYDEV_UCFG_DSI7_BASE Size (bytes): 128 */
#define BS_DSISWITCH_0_2_VAL ((const uint8 CYFAR *)0x0809C8)

/* DSI0_2_HV_ROUTING Address: CYDEV_UCFG_DSI7_BASE + 0x00000080 Size (bytes): 128 */
#define BS_DSI0_2_HV_ROUTING_VAL ((const uint8 CYFAR *)0x080A48)

/* DSI0_3_HV_ROUTING Address: CYDEV_UCFG_DSI6_BASE + 0x00000080 Size (bytes): 128 */
#define BS_DSI0_3_HV_ROUTING_VAL ((const uint8 CYFAR *)0x080AC8)

/* UDBSWITCH_0_0 Address: CYDEV_UCFG_B1_P5_ROUTE_BASE Size (bytes): 128 */
#define BS_UDBSWITCH_0_0_VAL ((const uint8 CYFAR *)0x080B48)

/* UDB_1_0_HV_ROUTING Address: CYDEV_UCFG_B1_P5_ROUTE_BASE + 0x00000080 Size (bytes): 128 */
#define BS_UDB_1_0_HV_ROUTING_VAL ((const uint8 CYFAR *)0x080BC8)

/* UDBSWITCH_1_0 Address: CYDEV_UCFG_B1_P2_ROUTE_BASE Size (bytes): 128 */
#define BS_UDBSWITCH_1_0_VAL ((const uint8 CYFAR *)0x080C48)

/* UDB_2_0_HV_ROUTING Address: CYDEV_UCFG_B1_P2_ROUTE_BASE + 0x00000080 Size (bytes): 128 */
#define BS_UDB_2_0_HV_ROUTING_VAL ((const uint8 CYFAR *)0x080CC8)

/* UDBSWITCH_0_1 Address: CYDEV_UCFG_B1_P4_ROUTE_BASE Size (bytes): 128 */
#define BS_UDBSWITCH_0_1_VAL ((const uint8 CYFAR *)0x080D48)

/* UDB_1_1_HV_ROUTING Address: CYDEV_UCFG_B1_P4_ROUTE_BASE + 0x00000080 Size (bytes): 128 */
#define BS_UDB_1_1_HV_ROUTING_VAL ((const uint8 CYFAR *)0x080DC8)

/* UDBSWITCH_1_1 Address: CYDEV_UCFG_B1_P3_ROUTE_BASE Size (bytes): 128 */
#define BS_UDBSWITCH_1_1_VAL ((const uint8 CYFAR *)0x080E48)

/* UDB_2_1_HV_ROUTING Address: CYDEV_UCFG_B1_P3_ROUTE_BASE + 0x00000080 Size (bytes): 128 */
#define BS_UDB_2_1_HV_ROUTING_VAL ((const uint8 CYFAR *)0x080EC8)

/* UDBSWITCH_0_2 Address: CYDEV_UCFG_B0_P4_ROUTE_BASE Size (bytes): 128 */
#define BS_UDBSWITCH_0_2_VAL ((const uint8 CYFAR *)0x080F48)

/* UDB_1_2_HV_ROUTING Address: CYDEV_UCFG_B0_P4_ROUTE_BASE + 0x00000080 Size (bytes): 128 */
#define BS_UDB_1_2_HV_ROUTING_VAL ((const uint8 CYFAR *)0x080FC8)

/* UDBSWITCH_1_2 Address: CYDEV_UCFG_B0_P3_ROUTE_BASE Size (bytes): 128 */
#define BS_UDBSWITCH_1_2_VAL ((const uint8 CYFAR *)0x081048)

/* UDB_2_2_HV_ROUTING Address: CYDEV_UCFG_B0_P3_ROUTE_BASE + 0x00000080 Size (bytes): 128 */
#define BS_UDB_2_2_HV_ROUTING_VAL ((const uint8 CYFAR *)0x0810C8)

/* UDBSWITCH_0_3 Address: CYDEV_UCFG_B0_P5_ROUTE_BASE Size (bytes): 128 */
#define BS_UDBSWITCH_0_3_VAL ((const uint8 CYFAR *)0x081148)

/* UDB_1_3_HV_ROUTING Address: CYDEV_UCFG_B0_P5_ROUTE_BASE + 0x00000080 Size (bytes): 128 */
#define BS_UDB_1_3_HV_ROUTING_VAL ((const uint8 CYFAR *)0x0811C8)

/* UDBSWITCH_1_3 Address: CYDEV_UCFG_B0_P2_ROUTE_BASE Size (bytes): 128 */
#define BS_UDBSWITCH_1_3_VAL ((const uint8 CYFAR *)0x081248)

/* UDB_2_3_HV_ROUTING Address: CYDEV_UCFG_B0_P2_ROUTE_BASE + 0x00000080 Size (bytes): 128 */
#define BS_UDB_2_3_HV_ROUTING_VAL ((const uint8 CYFAR *)0x0812C8)

/* UDBSWITCH_0_4 Address: CYDEV_UCFG_B0_P6_ROUTE_BASE Size (bytes): 128 */
#define BS_UDBSWITCH_0_4_VAL ((const uint8 CYFAR *)0x081348)

/* UDB_1_4_HV_ROUTING Address: CYDEV_UCFG_B0_P6_ROUTE_BASE + 0x00000080 Size (bytes): 128 */
#define BS_UDB_1_4_HV_ROUTING_VAL ((const uint8 CYFAR *)0x0813C8)

/* UDBSWITCH_1_4 Address: CYDEV_UCFG_B0_P1_ROUTE_BASE Size (bytes): 128 */
#define BS_UDBSWITCH_1_4_VAL ((const uint8 CYFAR *)0x081448)

/* UDB_2_4_HV_ROUTING Address: CYDEV_UCFG_B0_P1_ROUTE_BASE + 0x00000080 Size (bytes): 128 */
#define BS_UDB_2_4_HV_ROUTING_VAL ((const uint8 CYFAR *)0x0814C8)

/* UDBSWITCH_0_5 Address: CYDEV_UCFG_B0_P7_ROUTE_BASE Size (bytes): 128 */
#define BS_UDBSWITCH_0_5_VAL ((const uint8 CYFAR *)0x081548)

/* UDB_1_5_HV_ROUTING Address: CYDEV_UCFG_B0_P7_ROUTE_BASE + 0x00000080 Size (bytes): 128 */
#define BS_UDB_1_5_HV_ROUTING_VAL ((const uint8 CYFAR *)0x0815C8)

/* DSI3_0_HV_ROUTING Address: CYDEV_UCFG_DSI9_BASE + 0x00000080 Size (bytes): 128 */
#define BS_DSI3_0_HV_ROUTING_VAL ((const uint8 CYFAR *)0x081648)

/* DSISWITCH_1_1 Address: CYDEV_UCFG_DSI8_BASE Size (bytes): 128 */
#define BS_DSISWITCH_1_1_VAL ((const uint8 CYFAR *)0x0816C8)

/* DSI3_1_HV_ROUTING Address: CYDEV_UCFG_DSI8_BASE + 0x00000080 Size (bytes): 128 */
#define BS_DSI3_1_HV_ROUTING_VAL ((const uint8 CYFAR *)0x081748)

/* DSISWITCH_1_2 Address: CYDEV_UCFG_DSI3_BASE Size (bytes): 128 */
#define BS_DSISWITCH_1_2_VAL ((const uint8 CYFAR *)0x0817C8)

/* DSI3_2_HV_ROUTING Address: CYDEV_UCFG_DSI3_BASE + 0x00000080 Size (bytes): 128 */
#define BS_DSI3_2_HV_ROUTING_VAL ((const uint8 CYFAR *)0x081848)

/* DSISWITCH_1_3 Address: CYDEV_UCFG_DSI2_BASE Size (bytes): 128 */
#define BS_DSISWITCH_1_3_VAL ((const uint8 CYFAR *)0x0818C8)

/* DSI3_3_HV_ROUTING Address: CYDEV_UCFG_DSI2_BASE + 0x00000080 Size (bytes): 128 */
#define BS_DSI3_3_HV_ROUTING_VAL ((const uint8 CYFAR *)0x081948)

/* DSISWITCH_1_4 Address: CYDEV_UCFG_DSI1_BASE Size (bytes): 128 */
#define BS_DSISWITCH_1_4_VAL ((const uint8 CYFAR *)0x0819C8)

/* DSI3_4_HV_ROUTING Address: CYDEV_UCFG_DSI1_BASE + 0x00000080 Size (bytes): 128 */
#define BS_DSI3_4_HV_ROUTING_VAL ((const uint8 CYFAR *)0x081A48)

/* UCFG_BCTL1 Address: CYDEV_UCFG_BCTL1_MDCLK_EN Size (bytes): 16 */
#define BS_UCFG_BCTL1_VAL ((const uint8 CYFAR *)0x081AC8)

/* UCFG_BCTL0 Address: CYDEV_UCFG_BCTL0_MDCLK_EN Size (bytes): 16 */
#define BS_UCFG_BCTL0_VAL ((const uint8 CYFAR *)0x081AD8)

/* IOPINS0_7 Address: CYDEV_IO_PRT_PRT12_DM0 Size (bytes): 8 */
#define BS_IOPINS0_7_VAL ((const uint8 CYFAR *)0x081AE8)

/* IOPINS0_3 Address: CYDEV_IO_PRT_PRT3_DM0 Size (bytes): 8 */
#define BS_IOPINS0_3_VAL ((const uint8 CYFAR *)0x081AF0)

/* IOPINS0_5 Address: CYDEV_IO_PRT_PRT5_DM0 Size (bytes): 8 */
#define BS_IOPINS0_5_VAL ((const uint8 CYFAR *)0x081AF8)

/* IOPORT_5 Address: CYDEV_PRTDSI_PRT5_BASE Size (bytes): 7 */
#define BS_IOPORT_5_VAL ((const uint8 CYFAR *)0x081B00)

/* IOPORT_7 Address: CYDEV_PRTDSI_PRT12_BASE Size (bytes): 6 */
#define BS_IOPORT_7_VAL ((const uint8 CYFAR *)0x081B08)


static const uint8 CYCODE CH1_ADDR_DATA0[] DMAINITSEC = { 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };

static const uint8 CYCODE CH2_ADDR_DATA0[] DMAINITSEC = { 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00 };

static const uint8 CYCODE CH5_ADDR_DATA0[] DMAINITSEC = { 0x10, 0x00, 0x00, 0x00, 0x08, 0x00, 0x00, 0x00 };

static const uint8 CYCODE CH6_ADDR_DATA0[] DMAINITSEC = { 0x10, 0x00, 0x00, 0x00, 0x08, 0x00, 0x01, 0x00 };

static const uint8 CYCODE DMA_TD_START_CMD[] DMAINITSEC = { 0x01, 0x00, 0x00, 0x00, 0x01 };

static uint32 CYXDATA DMA_ZERO_VAL CYALIGNED;

static const struct td_t CYCODE CFG_TD_LIST0[] DMAINITSEC = {
/* Size, Flags, Next, Source, Destination */
	{ 8, 0x23, 0x02, (uint16)(&CH1_ADDR_DATA0), (uint16)(CYDEV_PHUB_CFGMEM1_CFG0) },	/* TD 1 */
	{ 8, 0x23, 0x03, (uint16)(&CH2_ADDR_DATA0), (uint16)(CYDEV_PHUB_CFGMEM2_CFG0) },	/* TD 2 */
	{ 8, 0x23, 0x04, (uint16)(&CH5_ADDR_DATA0), (uint16)(CYDEV_PHUB_CFGMEM5_CFG0) },	/* TD 3 */
	{ 8, 0x23, 0x05, (uint16)(&CH6_ADDR_DATA0), (uint16)(CYDEV_PHUB_CFGMEM6_CFG0) },	/* TD 4 */
	{ 5, 0x23, 0x06, (uint16)(&DMA_TD_START_CMD), (uint16)(CYDEV_PHUB_CH1_BASIC_CFG) },	/* TD 5 */
	{ 5, 0x23, 0x07, (uint16)(&DMA_TD_START_CMD), (uint16)(CYDEV_PHUB_CH2_BASIC_CFG) },	/* TD 6 */
	{ 5, 0x23, 0x08, (uint16)(&DMA_TD_START_CMD), (uint16)(CYDEV_PHUB_CH5_BASIC_CFG) },	/* TD 7 */
	{ 5, 0x23, 0xFF, (uint16)(&DMA_TD_START_CMD), (uint16)(CYDEV_PHUB_CH6_BASIC_CFG) },	/* TD 8 */
	{ 48, 0x22, 0x0A, (uint16)(&DMA_ZERO_VAL), (uint16)(CYDEV_IO_PRT_PRT0_DR) },	/* TD 9 */
	{ 16, 0x22, 0x0B, (uint16)(&DMA_ZERO_VAL), (uint16)(CYDEV_IO_PRT_PRT4_DR) },	/* TD 10 */
	{ 16, 0x22, 0x0C, (uint16)(&DMA_ZERO_VAL), (uint16)(CYDEV_IO_PRT_PRT6_DR) },	/* TD 11 */
	{ 16, 0x22, 0xFF, (uint16)(&DMA_ZERO_VAL), (uint16)(CYDEV_IO_PRT_PRT15_DR) },	/* TD 12 */
	{ 512, 0x22, 0x0E, (uint16)(&DMA_ZERO_VAL), (uint16)(CYDEV_UCFG_B0_P0_U0_BASE) },	/* TD 13 */
	{ 128, 0x22, 0x0F, (uint16)(&DMA_ZERO_VAL), (uint16)(CYDEV_UCFG_B0_P6_U1_BASE) },	/* TD 14 */
	{ 128, 0x22, 0x10, (uint16)(&DMA_ZERO_VAL), (uint16)(CYDEV_UCFG_B0_P7_U0_BASE) },	/* TD 15 */
	{ 128, 0x22, 0x11, (uint16)(&DMA_ZERO_VAL), (uint16)(CYDEV_UCFG_B1_P4_U1_BASE) },	/* TD 16 */
	{ 256, 0x22, 0x12, (uint16)(&DMA_ZERO_VAL), (uint16)(CYDEV_UCFG_DSI0_BASE) },	/* TD 17 */
	{ 640, 0x22, 0x13, (uint16)(&DMA_ZERO_VAL), (uint16)(CYDEV_UCFG_DSI4_BASE) },	/* TD 18 */
	{ 128, 0x22, 0x14, (uint16)(&DMA_ZERO_VAL), (uint16)(CYDEV_UCFG_DSI9_BASE) },	/* TD 19 */
	{ 512, 0x22, 0xFF, (uint16)(&DMA_ZERO_VAL), (uint16)(CYDEV_UCFG_DSI12_BASE) },	/* TD 20 */
	{ 32, 0x23, 0x16, (uint16)(BS_UWRK_B0_WRK_STATCTL_BITS_VAL), (uint16)(CYDEV_UWRK_UWRK8_B0_BASE + 0x00000070) },	/* TD 21 */
	{ 32, 0x23, 0xFF, (uint16)(BS_UWRK_B1_WRK_STATCTL_BITS_VAL), (uint16)(CYDEV_UWRK_UWRK8_B1_BASE + 0x00000070) },	/* TD 22 */
	{ 8, 0x23, 0x18, (uint16)(BS_IDMUX_IRQ_VAL), (uint16)(CYDEV_IDMUX_IRQ_CTL0) },	/* TD 23 */
	{ 128, 0x23, 0x19, (uint16)(BS_UDB_1_4_1_CONFIG_VAL), (uint16)(CYDEV_UCFG_B0_P1_U0_BASE) },	/* TD 24 */
	{ 128, 0x23, 0x1A, (uint16)(BS_UDB_1_4_0_CONFIG_VAL), (uint16)(CYDEV_UCFG_B0_P1_U1_BASE) },	/* TD 25 */
	{ 128, 0x23, 0x1B, (uint16)(BS_UDB_1_3_0_CONFIG_VAL), (uint16)(CYDEV_UCFG_B0_P2_U0_BASE) },	/* TD 26 */
	{ 128, 0x23, 0x1C, (uint16)(BS_UDB_1_3_1_CONFIG_VAL), (uint16)(CYDEV_UCFG_B0_P2_U1_BASE) },	/* TD 27 */
	{ 128, 0x23, 0x1D, (uint16)(BS_UDB_1_2_1_CONFIG_VAL), (uint16)(CYDEV_UCFG_B0_P3_U0_BASE) },	/* TD 28 */
	{ 128, 0x23, 0x1E, (uint16)(BS_UDB_1_2_0_CONFIG_VAL), (uint16)(CYDEV_UCFG_B0_P3_U1_BASE) },	/* TD 29 */
	{ 128, 0x23, 0x1F, (uint16)(BS_UDB_0_2_1_CONFIG_VAL), (uint16)(CYDEV_UCFG_B0_P4_U0_BASE) },	/* TD 30 */
	{ 128, 0x23, 0x20, (uint16)(BS_UDB_0_2_0_CONFIG_VAL), (uint16)(CYDEV_UCFG_B0_P4_U1_BASE) },	/* TD 31 */
	{ 128, 0x23, 0x21, (uint16)(BS_UDB_0_3_0_CONFIG_VAL), (uint16)(CYDEV_UCFG_B0_P5_U0_BASE) },	/* TD 32 */
	{ 128, 0x23, 0x22, (uint16)(BS_UDB_0_3_1_CONFIG_VAL), (uint16)(CYDEV_UCFG_B0_P5_U1_BASE) },	/* TD 33 */
	{ 128, 0x23, 0x23, (uint16)(BS_UDB_0_4_1_CONFIG_VAL), (uint16)(CYDEV_UCFG_B0_P6_U0_BASE) },	/* TD 34 */
	{ 128, 0x23, 0x24, (uint16)(BS_UDB_0_5_1_CONFIG_VAL), (uint16)(CYDEV_UCFG_B0_P7_U1_BASE) },	/* TD 35 */
	{ 128, 0x23, 0x25, (uint16)(BS_UDB_1_0_0_CONFIG_VAL), (uint16)(CYDEV_UCFG_B1_P2_U0_BASE) },	/* TD 36 */
	{ 128, 0x23, 0x26, (uint16)(BS_UDB_1_0_1_CONFIG_VAL), (uint16)(CYDEV_UCFG_B1_P2_U1_BASE) },	/* TD 37 */
	{ 128, 0x23, 0x27, (uint16)(BS_UDB_1_1_1_CONFIG_VAL), (uint16)(CYDEV_UCFG_B1_P3_U0_BASE) },	/* TD 38 */
	{ 128, 0x23, 0x28, (uint16)(BS_UDB_1_1_0_CONFIG_VAL), (uint16)(CYDEV_UCFG_B1_P3_U1_BASE) },	/* TD 39 */
	{ 128, 0x23, 0x29, (uint16)(BS_UDB_0_1_1_CONFIG_VAL), (uint16)(CYDEV_UCFG_B1_P4_U0_BASE) },	/* TD 40 */
	{ 128, 0x23, 0x2A, (uint16)(BS_UDB_0_0_0_CONFIG_VAL), (uint16)(CYDEV_UCFG_B1_P5_U0_BASE) },	/* TD 41 */
	{ 128, 0x23, 0x2B, (uint16)(BS_UDB_0_0_1_CONFIG_VAL), (uint16)(CYDEV_UCFG_B1_P5_U1_BASE) },	/* TD 42 */
	{ 128, 0x23, 0x2C, (uint16)(BS_DSISWITCH_0_2_VAL), (uint16)(CYDEV_UCFG_DSI7_BASE) },	/* TD 43 */
	{ 128, 0x23, 0x2D, (uint16)(BS_DSI0_2_HV_ROUTING_VAL), (uint16)(CYDEV_UCFG_DSI7_BASE + 0x00000080) },	/* TD 44 */
	{ 128, 0x23, 0x2E, (uint16)(BS_DSI0_3_HV_ROUTING_VAL), (uint16)(CYDEV_UCFG_DSI6_BASE + 0x00000080) },	/* TD 45 */
	{ 128, 0x23, 0x2F, (uint16)(BS_UDBSWITCH_0_0_VAL), (uint16)(CYDEV_UCFG_B1_P5_ROUTE_BASE) },	/* TD 46 */
	{ 128, 0x23, 0x30, (uint16)(BS_UDB_1_0_HV_ROUTING_VAL), (uint16)(CYDEV_UCFG_B1_P5_ROUTE_BASE + 0x00000080) },	/* TD 47 */
	{ 128, 0x23, 0x31, (uint16)(BS_UDBSWITCH_1_0_VAL), (uint16)(CYDEV_UCFG_B1_P2_ROUTE_BASE) },	/* TD 48 */
	{ 128, 0x23, 0x32, (uint16)(BS_UDB_2_0_HV_ROUTING_VAL), (uint16)(CYDEV_UCFG_B1_P2_ROUTE_BASE + 0x00000080) },	/* TD 49 */
	{ 128, 0x23, 0x33, (uint16)(BS_UDBSWITCH_0_1_VAL), (uint16)(CYDEV_UCFG_B1_P4_ROUTE_BASE) },	/* TD 50 */
	{ 128, 0x23, 0x34, (uint16)(BS_UDB_1_1_HV_ROUTING_VAL), (uint16)(CYDEV_UCFG_B1_P4_ROUTE_BASE + 0x00000080) },	/* TD 51 */
	{ 128, 0x23, 0x35, (uint16)(BS_UDBSWITCH_1_1_VAL), (uint16)(CYDEV_UCFG_B1_P3_ROUTE_BASE) },	/* TD 52 */
	{ 128, 0x23, 0x36, (uint16)(BS_UDB_2_1_HV_ROUTING_VAL), (uint16)(CYDEV_UCFG_B1_P3_ROUTE_BASE + 0x00000080) },	/* TD 53 */
	{ 128, 0x23, 0x37, (uint16)(BS_UDBSWITCH_0_2_VAL), (uint16)(CYDEV_UCFG_B0_P4_ROUTE_BASE) },	/* TD 54 */
	{ 128, 0x23, 0x38, (uint16)(BS_UDB_1_2_HV_ROUTING_VAL), (uint16)(CYDEV_UCFG_B0_P4_ROUTE_BASE + 0x00000080) },	/* TD 55 */
	{ 128, 0x23, 0x39, (uint16)(BS_UDBSWITCH_1_2_VAL), (uint16)(CYDEV_UCFG_B0_P3_ROUTE_BASE) },	/* TD 56 */
	{ 128, 0x23, 0x3A, (uint16)(BS_UDB_2_2_HV_ROUTING_VAL), (uint16)(CYDEV_UCFG_B0_P3_ROUTE_BASE + 0x00000080) },	/* TD 57 */
	{ 128, 0x23, 0x3B, (uint16)(BS_UDBSWITCH_0_3_VAL), (uint16)(CYDEV_UCFG_B0_P5_ROUTE_BASE) },	/* TD 58 */
	{ 128, 0x23, 0x3C, (uint16)(BS_UDB_1_3_HV_ROUTING_VAL), (uint16)(CYDEV_UCFG_B0_P5_ROUTE_BASE + 0x00000080) },	/* TD 59 */
	{ 128, 0x23, 0x3D, (uint16)(BS_UDBSWITCH_1_3_VAL), (uint16)(CYDEV_UCFG_B0_P2_ROUTE_BASE) },	/* TD 60 */
	{ 128, 0x23, 0x3E, (uint16)(BS_UDB_2_3_HV_ROUTING_VAL), (uint16)(CYDEV_UCFG_B0_P2_ROUTE_BASE + 0x00000080) },	/* TD 61 */
	{ 128, 0x23, 0x3F, (uint16)(BS_UDBSWITCH_0_4_VAL), (uint16)(CYDEV_UCFG_B0_P6_ROUTE_BASE) },	/* TD 62 */
	{ 128, 0x23, 0x40, (uint16)(BS_UDB_1_4_HV_ROUTING_VAL), (uint16)(CYDEV_UCFG_B0_P6_ROUTE_BASE + 0x00000080) },	/* TD 63 */
	{ 128, 0x23, 0x41, (uint16)(BS_UDBSWITCH_1_4_VAL), (uint16)(CYDEV_UCFG_B0_P1_ROUTE_BASE) },	/* TD 64 */
	{ 128, 0x23, 0x42, (uint16)(BS_UDB_2_4_HV_ROUTING_VAL), (uint16)(CYDEV_UCFG_B0_P1_ROUTE_BASE + 0x00000080) },	/* TD 65 */
	{ 128, 0x23, 0x43, (uint16)(BS_UDBSWITCH_0_5_VAL), (uint16)(CYDEV_UCFG_B0_P7_ROUTE_BASE) },	/* TD 66 */
	{ 128, 0x23, 0x44, (uint16)(BS_UDB_1_5_HV_ROUTING_VAL), (uint16)(CYDEV_UCFG_B0_P7_ROUTE_BASE + 0x00000080) },	/* TD 67 */
	{ 128, 0x23, 0x45, (uint16)(BS_DSI3_0_HV_ROUTING_VAL), (uint16)(CYDEV_UCFG_DSI9_BASE + 0x00000080) },	/* TD 68 */
	{ 128, 0x23, 0x46, (uint16)(BS_DSISWITCH_1_1_VAL), (uint16)(CYDEV_UCFG_DSI8_BASE) },	/* TD 69 */
	{ 128, 0x23, 0x47, (uint16)(BS_DSI3_1_HV_ROUTING_VAL), (uint16)(CYDEV_UCFG_DSI8_BASE + 0x00000080) },	/* TD 70 */
	{ 128, 0x23, 0x48, (uint16)(BS_DSISWITCH_1_2_VAL), (uint16)(CYDEV_UCFG_DSI3_BASE) },	/* TD 71 */
	{ 128, 0x23, 0x49, (uint16)(BS_DSI3_2_HV_ROUTING_VAL), (uint16)(CYDEV_UCFG_DSI3_BASE + 0x00000080) },	/* TD 72 */
	{ 128, 0x23, 0x4A, (uint16)(BS_DSISWITCH_1_3_VAL), (uint16)(CYDEV_UCFG_DSI2_BASE) },	/* TD 73 */
	{ 128, 0x23, 0x4B, (uint16)(BS_DSI3_3_HV_ROUTING_VAL), (uint16)(CYDEV_UCFG_DSI2_BASE + 0x00000080) },	/* TD 74 */
	{ 128, 0x23, 0x4C, (uint16)(BS_DSISWITCH_1_4_VAL), (uint16)(CYDEV_UCFG_DSI1_BASE) },	/* TD 75 */
	{ 128, 0x23, 0x4D, (uint16)(BS_DSI3_4_HV_ROUTING_VAL), (uint16)(CYDEV_UCFG_DSI1_BASE + 0x00000080) },	/* TD 76 */
	{ 16, 0x23, 0x4E, (uint16)(BS_UCFG_BCTL1_VAL), (uint16)(CYDEV_UCFG_BCTL1_MDCLK_EN) },	/* TD 77 */
	{ 16, 0x23, 0xFF, (uint16)(BS_UCFG_BCTL0_VAL), (uint16)(CYDEV_UCFG_BCTL0_MDCLK_EN) },	/* TD 78 */
};
static void cfg_dma_init(void)
{
	DMA_ZERO_VAL = 0u;
	DMAC_CFGMEM[0].CFG0[0] = 0x10;		/* set burstcount */
	DMAC_CH[0].basic_cfg[0] = 0x01u;	/* enable channel0 */
	DMAC_CH[0].basic_status[1] = 0;		/* set channel0's first td to 0 */
	
	DMAC_TDMEM[0].TD0[2] = 0x01;		/* set td0's next td to 1 */
	DMAC_TDMEM[0].TD0[3] = 0xA3;		/* set td0's flags */
	CY_SET_REG16((reg16 *) &DMAC_TDMEM[0].TD0[0], 78*8);					/* set td0's size */
	CY_SET_REG16((reg16 *) &DMAC_TDMEM[0].TD1[0], (uint16)(uint32)CFG_TD_LIST0);	/* set td0's src addr */
	CY_SET_REG16((reg16 *) &DMAC_TDMEM[0].TD1[2], CYDEV_PHUB_TDMEM1_BASE);	/* set td0's dst addr */
	CY_SET_REG16((reg16 *) &DMAC_CFGMEM[0].CFG1[0], (uint16)(CYDEV_FLS_BASE >> 16));				/* set ch0's src high addr */
	CY_SET_REG16((reg16 *) &DMAC_CFGMEM[0].CFG1[2], (uint16)(CYDEV_PHUB_TDMEM1_BASE >> 16));				/* set ch0's dst high addr */
	DMAC_CH[1].basic_status[1] = 0x09;
	DMAC_CH[2].basic_status[1] = 0x0D;
	DMAC_CH[5].basic_status[1] = 0x15;
	DMAC_CH[6].basic_status[1] = 0x17;

	CY_CFG_MEMORY_BARRIER();
	DMAC_CH[0].action[0] = CPU_REQ;    /* initiate the DMA transfer */
	CY_CFG_MEMORY_BARRIER();

	while((CY_GET_REG8(CYDEV_PHUB_CH0_BASIC_STATUS) & 0x01u)){}
	while((CY_GET_REG8(CYDEV_PHUB_CH1_BASIC_STATUS) & 0x01u)){}
	while((CY_GET_REG8(CYDEV_PHUB_CH2_BASIC_STATUS) & 0x01u)){}
	while((CY_GET_REG8(CYDEV_PHUB_CH5_BASIC_STATUS) & 0x01u)){}
	while((CY_GET_REG8(CYDEV_PHUB_CH6_BASIC_STATUS) & 0x01u)){}

	CY_SET_REG8(CYDEV_PHUB_CH0_BASIC_CFG, 0x00);
	CY_SET_REG8(CYDEV_PHUB_CH1_BASIC_CFG, 0x00);
	CY_SET_REG8(CYDEV_PHUB_CH2_BASIC_CFG, 0x00);
	CY_SET_REG8(CYDEV_PHUB_CH5_BASIC_CFG, 0x00);
	CY_SET_REG8(CYDEV_PHUB_CH6_BASIC_CFG, 0x00);

}
static void ClockSetup(void)
{
	reg32  timeout;
	reg32* timeout_p = &timeout;
	reg8   pllLock;

	CY_SET_XTND_REG24((void CYFAR *)(CYDEV_CLKDIST_DCFG0_CFG0), 0x180002);
	CY_SET_XTND_REG24((void CYFAR *)(CYDEV_CLKDIST_DCFG1_CFG0), 0x180033);
	CY_SET_REG8((void CYXDATA *)(CYDEV_SLOWCLK_ILO_CR0), 0x02);
	CY_SET_REG8((void CYXDATA *)(CYDEV_CLKDIST_CR), 0x08);
	CY_SET_REG8((void CYXDATA *)(CYDEV_FASTCLK_IMO_CR), 0x03);
	CY_SET_REG8((void CYXDATA *)(CYDEV_MFGCFG_IMO_TR1), (CY_GET_XTND_REG8(CYDEV_FLSHID_CUST_TABLES_IMO_3MHZ)));
	CY_SET_XTND_REG16((void CYFAR *)(CYDEV_FASTCLK_PLL_P), 0x0008);
	CY_SET_REG8((void CYXDATA *)(CYDEV_CLKDIST_CR), 0x08);
	CY_SET_XTND_REG16((void CYFAR *)(CYDEV_FASTCLK_PLL_CFG0), 0x1051);
	pllLock = 0;
	for (timeout = 56; *timeout_p && (pllLock != 0x03u); timeout--) { pllLock = 0x03u & ((pllLock << 1) | ((CY_GET_REG8(CYDEV_FASTCLK_PLL_SR) & 0x01u) >> 0)); }
	CY_SET_XTND_REG16((void CYFAR *)(CYDEV_CLKDIST_MSTR0), 0x0103);
	CY_SET_REG8((void CYXDATA *)(CYDEV_CLKDIST_MSTR0), 0x00);
	CY_SET_REG8((void CYXDATA *)(CYDEV_CLKDIST_MSTR0), 0x07);
	CY_SET_REG8((void CYXDATA *)(CYDEV_CLKDIST_BCFG0), 0x00);
	CY_SET_REG8((void CYXDATA *)(CYDEV_CLKDIST_BCFG2), 0x48);
	CY_SET_REG8((void CYXDATA *)(CYDEV_CLKDIST_MSTR0), 0x00);
	CY_SET_REG8((void CYXDATA *)(CYDEV_CLKDIST_LD), 0x02);

	CY_SET_REG8((void CYXDATA *)(CYDEV_PM_ACT_CFG2), ((CY_GET_REG8(CYDEV_PM_ACT_CFG2) | 0x03)));
}

/* Analog API Functions */
void AnalogSetDefault(void)
{
	CY_SET_REG8(CYDEV_IO_PRT_PRT12_AG, 0xAA);
	CY_SET_REG8(CYDEV_ANAIF_CFG_PUMP_CR0, 0x44);
}

#define CY_AMUX_UNUSED CYDEV_BOOST_SR

/* This function is called by the start-up code for the selected device. */
void cyfitter_cfg(void)
{
	CY_SET_REG8((void CYXDATA *)(CYDEV_CACHE_CR), ((CYDEV_INSTRUCT_CACHE_ENABLED) ? 0x90 : 0x80));
	CY_SET_REG8((void CYXDATA *)(CYDEV_PHUB_CH0_BASIC_CFG), 0x00);
	CY_SET_REG8((void CYXDATA *)(CYDEV_PHUB_CH1_BASIC_CFG), 0x00);

	CY_SET_XTND_REG8(CYDEV_MFGCFG_MLOGIC_DBG_EN_DBG_EN, (CY_GET_XTND_REG8(CYDEV_MFGCFG_MLOGIC_DBG_EN_DBG_EN) | 0x01));
	cfg_dma_init();

	CYMEMZERO8((void CYFAR *)(CYDEV_PRTDSI_PRT0_BASE), 7);
	CYMEMZERO8((void CYFAR *)(CYDEV_PRTDSI_PRT1_BASE), 7);
	CYMEMZERO8((void CYFAR *)(CYDEV_PRTDSI_PRT2_BASE), 7);
	CYMEMZERO8((void CYFAR *)(CYDEV_PRTDSI_PRT3_BASE), 7);
	CYMEMZERO8((void CYFAR *)(CYDEV_PRTDSI_PRT4_BASE), 7);
	CYCONFIGCPY8((void CYFAR *)(CYDEV_PRTDSI_PRT5_BASE), (void CYFAR *)(BS_IOPORT_5_VAL), 7);
	CYMEMZERO8((void CYFAR *)(CYDEV_PRTDSI_PRT6_BASE), 7);
	CYCONFIGCPY8((void CYFAR *)(CYDEV_PRTDSI_PRT12_BASE), (void CYFAR *)(BS_IOPORT_7_VAL), 6);
	CYMEMZERO8((void CYFAR *)(CYDEV_PRTDSI_PRT15_BASE), 7);
	/* BYTES WRITTEN: 62 */

	/* Enable digital routing */
	CY_SET_XTND_REG8(CYDEV_UCFG_BCTL0_BANK_CTL, CY_GET_XTND_REG8(CYDEV_UCFG_BCTL0_BANK_CTL) | 0x02u);
	CY_SET_XTND_REG8(CYDEV_UCFG_BCTL1_BANK_CTL, CY_GET_XTND_REG8(CYDEV_UCFG_BCTL1_BANK_CTL) | 0x02u);

	/* Enable UDB array */
	CY_SET_REG8(CYDEV_PM_ACT_CFG0, CY_GET_REG8(CYDEV_PM_ACT_CFG0) | 0x40u);
	CY_SET_REG8(CYDEV_PM_AVAIL_CR2, CY_GET_REG8(CYDEV_PM_AVAIL_CR2) | 0x10u);

	CYCONFIGCPY8((void CYFAR *)(CYDEV_IO_PRT_PRT12_DM0), (void CYFAR *)(BS_IOPINS0_7_VAL), 8);
	CYCONFIGCPY((void CYFAR *)(CYDEV_IO_PRT_PRT3_DM0), (void CYFAR *)(BS_IOPINS0_3_VAL), 8);
	CYCONFIGCPY((void CYFAR *)(CYDEV_IO_PRT_PRT5_DM0), (void CYFAR *)(BS_IOPINS0_5_VAL), 8);
	CY_SET_REG8((void CYXDATA *)(CYDEV_INTC_CLOCK_EN), 0x01);
	/* BYTES WRITTEN: 25 */

	CY_SET_REG8((void CYXDATA *)(CYDEV_CACHE_CR), ((CYDEV_INSTRUCT_CACHE_ENABLED) ? 0x10 : 0x00));
	ClockSetup();
	CY_SET_REG8((void CYXDATA *)(CYDEV_CACHE_CR), ((CYDEV_INSTRUCT_CACHE_ENABLED) ? 0x50 : 0x40));

	AnalogSetDefault();

	/* Configure alternate active mode */
	CYCONFIGCPY((void CYFAR *)CYDEV_PM_STBY_BASE, (void CYFAR *)CYDEV_PM_ACT_BASE, 12);
	CY_SET_REG8(CYDEV_PM_STBY_CFG0, CY_GET_REG8(CYDEV_PM_STBY_CFG0) & ~0x02u);	/* Disable CPU */
}
